@@ -57,6 +57,8 @@ class State(DataClassJSONMixin):
         The current temperature of the climate system.
     room1_thermostat_mode : EntityInfo
         The thermostat mode of the climate system.
+    room1_temp_setpoint_boost : EntityInfo
+        The temperature setpoint boost of the climate system.
 
     """
 
@@ -66,6 +68,7 @@ class State(DataClassJSONMixin):
     hvac_action: EntityInfo
     current_temperature: EntityInfo
     room1_thermostat_mode: EntityInfo
+    room1_temp_setpoint_boost: EntityInfo
 
 
 @dataclass
@@ -84,6 +87,22 @@ class Sensor(DataClassJSONMixin):
     outside_temperature: EntityInfo
 
 
+@dataclass
+class HotWaterState(DataClassJSONMixin):
+    """Object holds info about object for hot water climate."""
+
+    operating_mode: EntityInfo
+    nominal_setpoint: EntityInfo
+    nominal_setpoint_max: EntityInfo  # 1614
+    reduced_setpoint: EntityInfo
+    release: EntityInfo
+    legionella_function: EntityInfo
+    legionella_setpoint: EntityInfo
+    legionella_periodically: EntityInfo
+    dhw_actual_value_top_temperature: EntityInfo  # 8830
+    state_dhw_pump: EntityInfo  # 8820
+
+
 @dataclass
 class Device(DataClassJSONMixin):
     """Object holds bsblan device information.
